@@ -1,22 +1,22 @@
 #undef PACKAGE
 #undef VERSION
-#undef AT_BINDIR
 #undef GETTEXT_PACKAGE
-#undef GDM_DEFAULTS_CONF
-#undef GDM_CUSTOM_CONF
-#undef GDM_OLD_CONF
-#undef GDM_USER_PATH
 #undef HALT_COMMAND
 #undef REBOOT_COMMAND
 #undef SOUND_PROGRAM
 #undef SUSPEND_COMMAND
 #undef ENABLE_IPV6
 #undef ENABLE_NLS
+#undef ALWAYS_RESTART_SERVER
+#undef GDM_USER_PATH
+#undef GDM_RBAC_SYSCMD_KEYS
 #undef HAVE_ADT
 #undef HAVE_CATGETS
+#undef HAVE_CHKAUTHATTR
 #undef HAVE_CHPASS
 #undef HAVE_CLEARENV
 #undef HAVE_CRYPT
+#undef HAVE_CTRUN
 #undef HAVE_DEFOPEN
 #undef HAVE_FBCONSOLE
 #undef HAVE_GETTEXT
@@ -41,21 +41,11 @@
 #undef HAVE_XINERAMA
 #undef HAVE_XFREE_XINERAMA
 #undef HAVE_XINPUT
-#undef EXPANDED_AUTHDIR
-#undef EXPANDED_DATADIR
-#undef EXPANDED_BINDIR
-#undef EXPANDED_LIBEXECDIR
-#undef EXPANDED_LIBDIR
-#undef EXPANDED_LOCALEDIR
-#undef EXPANDED_LOGDIR
-#undef EXPANDED_PIXMAPDIR
-#undef EXPANDED_SBINDIR
-#undef EXPANDED_SYSCONFDIR
-#undef EXPANDED_SESSDIR
 #undef X_SERVER
 #undef X_SERVER_PATH
-#undef X_XNEST_PATH
+#undef X_XNEST_CMD
 #undef X_XNEST_CONFIG_OPTIONS
+#undef X_XNEST_UNSCALED_FONTPATH
 #undef X_CONFIG_OPTIONS
 #undef X_PATH
 #undef XSESSION_SHELL
