@@ -1,4 +1,6 @@
-/* GDM - The GNOME Display Manager
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,17 +23,19 @@
 
 #include "gdm.h"
 
-#ifdef ENABLE_IPV6
-GdmIndirectDisplay *   gdm_choose_indirect_alloc (struct sockaddr_storage *clnt_sa);
-GdmIndirectDisplay * gdm_choose_indirect_lookup (struct sockaddr_storage *clnt_sa);
-GdmIndirectDisplay * gdm_choose_indirect_lookup_by_chosen6 (struct in6_addr *chosen, struct in6_addr *origin);
-#else
-GdmIndirectDisplay *	gdm_choose_indirect_alloc (struct sockaddr_in *clnt_sa);
-GdmIndirectDisplay *	gdm_choose_indirect_lookup (struct sockaddr_in *clnt_sa);
-#endif
-GdmIndirectDisplay *	gdm_choose_indirect_lookup_by_chosen (struct in_addr *chosen,
-							      struct in_addr *origin);
-void			gdm_choose_indirect_dispose (GdmIndirectDisplay *id);
+typedef struct _GdmIndirectDisplay GdmIndirectDisplay;
+struct _GdmIndirectDisplay {
+	int id;
+	struct sockaddr_storage* dsp_sa;
+	struct sockaddr_storage* chosen_host;
+	time_t acctime;
+};
+
+GdmIndirectDisplay *    gdm_choose_indirect_alloc            (struct sockaddr_storage *clnt_sa);
+GdmIndirectDisplay *    gdm_choose_indirect_lookup           (struct sockaddr_storage *clnt_sa);
+GdmIndirectDisplay *	gdm_choose_indirect_lookup_by_chosen (struct sockaddr_storage *chosen,
+							      struct sockaddr_storage *origin);
+void			gdm_choose_indirect_dispose          (GdmIndirectDisplay *id);
 
 /* dispose of indirect display of id, if no host is set */
 void			gdm_choose_indirect_dispose_empty_id (guint id);
