@@ -19,9 +19,9 @@
 #ifndef GDM_COOKIE_H
 #define GDM_COOKIE_H
 
-#include "gdm.h"
+void gdm_cookie_generate (char **cookie,
+                          char **bcookie);
 
-void gdm_cookie_generate (GdmDisplay *);
 /* Add some more time based randomness, should be done
  * at less predictable events */
 void gdm_random_tick (void);
