@@ -317,7 +317,9 @@ parse_stock (xmlNodePtr node,
 	     GError   **error)
 {
   xmlChar *prop;
-  
+  int i = -1;
+  gchar * key_string = NULL;
+
   prop = xmlGetProp (node,(const xmlChar *) "type");
   if (prop)
     {
@@ -415,34 +417,22 @@ parse_stock (xmlNodePtr node,
           g_free (*translated_text);
           *translated_text = g_strdup (_("_Start Again"));
         }
-      else
+      else if (sscanf ((char *) prop, "custom_cmd%d", &i) == 1 && 
+	       i >= 0 && i < GDM_CUSTOM_COMMAND_MAX) 
         {
-	  gboolean is_error = TRUE;
-	  register int i = 0;
-	    for (; i < GDM_CUSTOM_COMMAND_MAX; i++) {
-		gchar * key_string = NULL;
-		key_string = g_strdup_printf ("custom_cmd%d", i);
-		if (g_ascii_strcasecmp ((char *) prop, key_string) == 0) {
-		    g_free (*translated_text);
-		    g_free (key_string);
-		    key_string = g_strdup_printf ("%s%d=", GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
-		    *translated_text = g_strdup(gdm_config_get_string (key_string));
-		    g_free (key_string);
-		    is_error = FALSE;
-		    break;
-		}
-		g_free (key_string);
-	    }
-	    
-	    if (is_error)
-	      {
-		g_set_error (error,
-		     GREETER_PARSER_ERROR,
-		     GREETER_PARSER_ERROR_BAD_SPEC,
-		     "Bad stock label type");
-		xmlFree (prop);
-		return FALSE;
-	      }
+	      key_string = g_strdup_printf ("%s%d=", GDM_KEY_CUSTOM_CMD_LABEL_TEMPLATE, i);
+	      g_free (*translated_text);
+	      *translated_text = g_strdup(gdm_config_get_string (key_string));
+	      g_free (key_string);
+	}
+      else
+      {
+	      g_set_error (error,
+			   GREETER_PARSER_ERROR,
+			   GREETER_PARSER_ERROR_BAD_SPEC,
+			   "Bad stock label type");
+	      xmlFree (prop);
+	      return FALSE;	      
 	}
 
       /* This is the very very very best "translation" */
@@ -1665,6 +1655,7 @@ parse_items (xmlNodePtr  node,
     GList *items;
     gboolean res;
     xmlChar *type;
+    xmlChar *background;
     GreeterItemInfo *info;
     GreeterItemType item_type;
 
@@ -1766,6 +1757,20 @@ parse_items (xmlNodePtr  node,
 
 	    if (info->canvasbutton)
 	      button_stack = g_list_remove (button_stack, info);
+
+	    background = xmlGetProp (child, (const xmlChar *) "background");
+	    if G_UNLIKELY (background)
+	      {
+		if (strcmp ((char *) background, "true") == 0)
+		   {
+		      info->background = TRUE;
+		   }
+		else if (strcmp ((char *) background, "false") == 0)
+		   {
+		      info->background = FALSE;
+		   }
+		xmlFree (background);
+	      }
 	    
 	    if G_UNLIKELY (!res)
 	      return FALSE;
@@ -1932,3 +1937,51 @@ greeter_custom_items (void)
 {
   return custom_items;
 }
+
+static void
+hide_item (GreeterItemInfo *info, gpointer user_data)
+{  
+	GnomeCanvasItem *item;
+	gboolean *found_background;
+
+	found_background = user_data;
+
+	if (info)
+       	{
+	     if (info->background)
+	     {
+		     *found_background = TRUE;
+	     }
+	     else {
+		item = info->item;
+	      	if (item) {
+			if (GNOME_IS_CANVAS_WIDGET (item)) {
+				gtk_widget_hide (GNOME_CANVAS_WIDGET (item)->widget);
+			}
+			else
+			gnome_canvas_item_hide (item);
+		}
+		if ((info->item_type == GREETER_ITEM_TYPE_ENTRY) &&
+			(info->data.text.menubar != NULL)) {
+				gtk_widget_hide (info->data.text.menubar);
+			}
+	     }
+
+	g_list_foreach (info->fixed_children, (GFunc) hide_item, user_data);
+	g_list_foreach (info->box_children, (GFunc) hide_item, user_data);
+      }
+}
+
+gboolean 
+greeter_show_only_background (GreeterItemInfo *root_item)
+{
+	gboolean found_background = FALSE;
+
+	hide_item (root_item, &found_background);
+
+	/* ensure root canvas is updated */
+	while (gtk_events_pending ())
+	  gtk_main_iteration ();
+
+	return found_background;
+}
